// 005 u_gof_abstract_factory
// 11 dec 2004

// -- Delphi implementation from the book:
// --   Design Patterns Elements of Reusable Object-Oriented Software
// --   Addison Wesley - 1994 - ISBN 0-201-63361-2
// -- (C) Erich GAMMA, Richard HELM, Ralph JOHNSON, John VLISSIDES 1994

// -- translation from C to Delphi performed by
// --   Felix John COLIBRI  http://www.felix-colibri.com

(*$r+*)

unit u_gof_abstract_factory;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ComCtrls, ExtCtrls;

type
  TForm1 = class(TForm)
    Memo1: TMemo;
    exit_: TButton;
    clear_: TButton;
    create_maze_: TButton;
    create_maze_with_factory_: TButton;
    create_enchanted_maze_: TButton;
    create_bombed_maze_: TButton;
    procedure FormCreate(Sender: TObject);
    procedure exit_Click(Sender: TObject);
    procedure clear_Click(Sender: TObject);
    procedure create_maze_Click(Sender: TObject);
    procedure create_maze_with_factory_Click(Sender: TObject);
    procedure create_enchanted_maze_Click(Sender: TObject);
    procedure create_bombed_maze_Click(Sender: TObject);
  private

  public

  end;

    var Form1: TForm1;

  implementation
    uses u_types_constants, u_c_log, u_c_display
        , u_dir, u_file

        , u_c_maze_1
        , u_c_maze_game_1

        , u_c_maze_factory_1
        , u_c_maze_game_1_2

        , u_c_enchanted_room_and_door_1
        , u_c_enchanted_maze_factory_1

        , u_c_bombed_room_and_wall_1
        , u_c_bombed_maze_factory_1
    ;

    {$R *.DFM}

 
    procedure TForm1.FormCreate(Sender: TObject);
      begin
        initialize_display(Memo1.Lines);
        initialize_default_log;
      end; // FormCreate

    procedure TForm1.exit_Click(Sender: TObject);
      begin
        Close;
      end; // close_Click

    procedure TForm1.clear_Click(Sender: TObject);
      begin
        clear_display;
      end; // clear_Click

    procedure TForm1.create_maze_Click(Sender: TObject);
      var l_c_maze_game: c_maze_game;
          l_c_maze: c_maze;
      begin
        l_c_maze_game:= c_maze_game.create_maze_game;

        with l_c_maze_game do
        begin
          l_c_maze:= f_c_create_maze;
          // ...
        end; // with c_maze_game
      end; // create_maze_Click

    procedure TForm1.create_maze_with_factory_Click(Sender: TObject);
      var l_c_maze_factory: c_maze_factory;
          l_c_maze: c_maze;
      begin
        l_c_maze_factory:= c_maze_factory.create_maze_factory;

        with c_maze_game_2.create_maze_game_2 do
        begin
          l_c_maze:= f_c_create_maze_2(l_c_maze_factory);
          // ...
        end; // with c_maze_game_2
      end; // create_maze_with_factory_Click

    procedure TForm1.create_enchanted_maze_Click(Sender: TObject);
      var l_c_enchanted_maze_factory: c_enchanted_maze_factory;
          l_c_maze: c_maze;
      begin
        l_c_enchanted_maze_factory:= c_enchanted_maze_factory.create_enchanted_maze_factory;

        with c_maze_game_2.create_maze_game_2 do
        begin
          l_c_maze:= f_c_create_maze_2(l_c_enchanted_maze_factory);
          // ...
        end; // with c_maze_game_2
      end; // create_enchanted_maze_Click

    procedure TForm1.create_bombed_maze_Click(Sender: TObject);
      var l_c_bombed_maze_factory: c_bombed_maze_factory;
          l_c_maze: c_maze;
      begin
        l_c_bombed_maze_factory:= c_bombed_maze_factory.create_bombed_maze_factory;

        with c_maze_game_2.create_maze_game_2 do
        begin
          l_c_maze:= f_c_create_maze_2(l_c_bombed_maze_factory);
          // ...
        end; // with c_maze_game_2
      end;

end.


